@@ -3,7 +3,7 @@
  * @category Horde
  * @package  Controller
  * @author   Gunnar Wrobel <wrobel@pardus.de>
- * @license  http://opensource.org/licenses/bsd-license.php BSD
+ * @license  http://www.horde.org/licenses/bsd BSD
  */
 class Horde_Controller_Request_Mock extends Horde_Controller_Request_Http
 {
@@ -53,4 +53,34 @@ class Horde_Controller_Request_Mock extends Horde_Controller_Request_Http
             return $this->_vars[$name];
         }
     }
+
+    public function getGetVars()
+    {
+        return $this->getVars('GET');
+    }
+
+    public function getFileVars()
+    {
+        return $this->getVars('FILES');
+    }
+
+    public function getServerVars()
+    {
+        return $this->getVars('SERVER');
+    }
+
+    public function getPostVars()
+    {
+        return $this->getVars('POST');
+    }
+
+    public function getCookieVars()
+    {
+        return $this->getVars('COOKIE');
+    }
+
+    public function getRequestVars()
+    {
+        return $this->getVars('REQUEST');
+    }
 }
