@@ -1,10 +1,5 @@
 <?php
 
-/**
- * Prepare the test setup.
- */
-require_once dirname(__FILE__) . '/Autoload.php';
-
 class Horde_Controller_StreamTest extends Horde_Test_Case
 {
     public function testStreamOutput()
@@ -16,6 +11,6 @@ class Horde_Controller_StreamTest extends Horde_Test_Case
         $writer = new Horde_Controller_ResponseWriter_Web();
         ob_start();
         $writer->writeResponse($response);
-        $this->assertEquals('BODY', ob_end_clean());
+        $this->assertEquals('BODY', ob_get_clean());
     }
-}
\ No newline at end of file
+}
